@@ -321,7 +321,7 @@ class GSPeerConnectionBroadcasterPiSocketv2:
             await self.sio.emit("joined", self.sio.sid)
 
         @self.sio.event
-        async def broadcaster(id, description):
+        async def broadcaster(id, description,emitter):
 
             if len(self.rtconfiList) > 0:
                 pc = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
