@@ -419,12 +419,13 @@ class GSPeerConnectionBroadcasterUniversalNew:
         await self.sio.wait()
 
 
-def createTerminatorView(gsdbs, aioqueue: asyncio.Queue, target, signalingserver=None
+async def createTerminatorView(gsdbs, aioqueue: asyncio.Queue, target, signalingserver=None
                          ):
-    return asyncio.gather(checkTerminatorQueue(aioqueue),
-                          GSPeerConnectionBroadcasterUniversalNew.create(gsdbs=gsdbs,
-                                                                         target=target + "terminatorview",
-                                                                         videostream=False,
-                                                                         videotrack=True,
-                                                                         signalingserver=signalingserver
-                                                                         ))
+    terminatorviewtask = await asyncio.gather(checkTerminatorQueue(aioqueue),
+                                              GSPeerConnectionBroadcasterUniversalNew.create(gsdbs=gsdbs,
+                                                                                             target=target + "terminatorview",
+                                                                                             videostream=False,
+                                                                                             videotrack=True,
+                                                                                             signalingserver=signalingserver
+                                                                                             ))
+    return terminatorviewtask
\ No newline at end of file
